summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--misc/drivers/rtl8187x/rtl8187x.c2
-rw-r--r--nuttx/arch/arm/src/c5471/c5471_ethernet.c2
-rw-r--r--nuttx/arch/arm/src/kinetis/kinetis_enet.c2
-rw-r--r--nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c2
-rw-r--r--nuttx/arch/arm/src/sam34/sam_emac.c2
-rw-r--r--nuttx/arch/arm/src/sama5/sam_emaca.c2
-rw-r--r--nuttx/arch/arm/src/sama5/sam_emacb.c2
-rw-r--r--nuttx/arch/arm/src/sama5/sam_gmac.c2
-rw-r--r--nuttx/arch/arm/src/stm32/stm32_eth.c2
-rw-r--r--nuttx/arch/arm/src/tiva/tiva_ethernet.c2
-rw-r--r--nuttx/arch/hc/src/m9s12/m9s12_ethernet.c2
-rw-r--r--nuttx/arch/mips/src/pic32mx/pic32mx-ethernet.c2
-rw-r--r--nuttx/arch/sim/src/up_uipdriver.c2
-rw-r--r--nuttx/arch/z80/src/ez80/ez80_emac.c2
-rw-r--r--nuttx/drivers/net/cs89x0.c2
-rw-r--r--nuttx/drivers/net/dm90x0.c2
-rw-r--r--nuttx/drivers/net/e1000.c2
-rw-r--r--nuttx/drivers/net/enc28j60.c2
-rw-r--r--nuttx/drivers/net/encx24j600.c2
-rw-r--r--nuttx/drivers/net/skeleton.c2
-rw-r--r--nuttx/drivers/net/slip.c2
-rw-r--r--nuttx/drivers/net/vnet.c2
-rw-r--r--nuttx/include/nuttx/net/netdev.h6
-rw-r--r--nuttx/net/devif/devif_input.c8
24 files changed, 29 insertions, 29 deletions
diff --git a/misc/drivers/rtl8187x/rtl8187x.c b/misc/drivers/rtl8187x/rtl8187x.c
index d056a7750..81bd40a22 100644
--- a/misc/drivers/rtl8187x/rtl8187x.c
+++ b/misc/drivers/rtl8187x/rtl8187x.c
@@ -2242,7 +2242,7 @@ static inline void rtl8187x_rxdispatch(FAR struct rtl8187x_state_s *priv,
{
RTL8187X_STATS(priv, rxippackets);
arp_ipin(&priv->ethdev);
- uip_input(&priv->ethdev);
+ devif_input(&priv->ethdev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/arm/src/c5471/c5471_ethernet.c b/nuttx/arch/arm/src/c5471/c5471_ethernet.c
index eace9d8d0..36efd78f9 100644
--- a/nuttx/arch/arm/src/c5471/c5471_ethernet.c
+++ b/nuttx/arch/arm/src/c5471/c5471_ethernet.c
@@ -1239,7 +1239,7 @@ static void c5471_receive(struct c5471_driver_s *c5471)
#endif
{
arp_ipin(dev);
- uip_input(dev);
+ devif_input(dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/arm/src/kinetis/kinetis_enet.c b/nuttx/arch/arm/src/kinetis/kinetis_enet.c
index 92c411453..7b243d041 100644
--- a/nuttx/arch/arm/src/kinetis/kinetis_enet.c
+++ b/nuttx/arch/arm/src/kinetis/kinetis_enet.c
@@ -523,7 +523,7 @@ static void kinetis_receive(FAR struct kinetis_driver_s *priv)
#endif
{
arp_ipin(&priv->dev);
- uip_input(&priv->dev);
+ devif_input(&priv->dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c b/nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c
index 3712d91bd..e0093fddb 100644
--- a/nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c
+++ b/nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c
@@ -868,7 +868,7 @@ static void lpc17_rxdone(struct lpc17_driver_s *priv)
EMAC_STAT(priv, rx_ip);
arp_ipin(&priv->lp_dev);
- uip_input(&priv->lp_dev);
+ devif_input(&priv->lp_dev);
/* If the above function invocation resulted in data that
* should be sent out on the network, the field d_len will
diff --git a/nuttx/arch/arm/src/sam34/sam_emac.c b/nuttx/arch/arm/src/sam34/sam_emac.c
index 58ed1e7be..e3bdecdb2 100644
--- a/nuttx/arch/arm/src/sam34/sam_emac.c
+++ b/nuttx/arch/arm/src/sam34/sam_emac.c
@@ -1140,7 +1140,7 @@ static void sam_receive(struct sam_emac_s *priv)
/* Handle ARP on input then give the IP packet to uIP */
arp_ipin(&priv->dev);
- uip_input(&priv->dev);
+ devif_input(&priv->dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/arm/src/sama5/sam_emaca.c b/nuttx/arch/arm/src/sama5/sam_emaca.c
index 3ec595cdf..fca5e2dfd 100644
--- a/nuttx/arch/arm/src/sama5/sam_emaca.c
+++ b/nuttx/arch/arm/src/sama5/sam_emaca.c
@@ -1180,7 +1180,7 @@ static void sam_receive(struct sam_emac_s *priv)
/* Handle ARP on input then give the IP packet to uIP */
arp_ipin(&priv->dev);
- uip_input(&priv->dev);
+ devif_input(&priv->dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/arm/src/sama5/sam_emacb.c b/nuttx/arch/arm/src/sama5/sam_emacb.c
index 802e5c1f6..0ac775d76 100644
--- a/nuttx/arch/arm/src/sama5/sam_emacb.c
+++ b/nuttx/arch/arm/src/sama5/sam_emacb.c
@@ -1495,7 +1495,7 @@ static void sam_receive(struct sam_emac_s *priv)
/* Handle ARP on input then give the IP packet to uIP */
arp_ipin(&priv->dev);
- uip_input(&priv->dev);
+ devif_input(&priv->dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/arm/src/sama5/sam_gmac.c b/nuttx/arch/arm/src/sama5/sam_gmac.c
index 2c2d0415a..f50a698a6 100644
--- a/nuttx/arch/arm/src/sama5/sam_gmac.c
+++ b/nuttx/arch/arm/src/sama5/sam_gmac.c
@@ -1110,7 +1110,7 @@ static void sam_receive(struct sam_gmac_s *priv)
/* Handle ARP on input then give the IP packet to uIP */
arp_ipin(&priv->dev);
- uip_input(&priv->dev);
+ devif_input(&priv->dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/arm/src/stm32/stm32_eth.c b/nuttx/arch/arm/src/stm32/stm32_eth.c
index a17d140db..17cc58a7c 100644
--- a/nuttx/arch/arm/src/stm32/stm32_eth.c
+++ b/nuttx/arch/arm/src/stm32/stm32_eth.c
@@ -1623,7 +1623,7 @@ static void stm32_receive(FAR struct stm32_ethmac_s *priv)
/* Handle ARP on input then give the IP packet to uIP */
arp_ipin(&priv->dev);
- uip_input(&priv->dev);
+ devif_input(&priv->dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/arm/src/tiva/tiva_ethernet.c b/nuttx/arch/arm/src/tiva/tiva_ethernet.c
index 773e6cbb3..f33f497f5 100644
--- a/nuttx/arch/arm/src/tiva/tiva_ethernet.c
+++ b/nuttx/arch/arm/src/tiva/tiva_ethernet.c
@@ -767,7 +767,7 @@ static void tiva_receive(struct tiva_driver_s *priv)
EMAC_STAT(priv, rx_ip);
arp_ipin(&priv->ld_dev);
- uip_input(&priv->ld_dev);
+ devif_input(&priv->ld_dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/hc/src/m9s12/m9s12_ethernet.c b/nuttx/arch/hc/src/m9s12/m9s12_ethernet.c
index 6d572503b..9b759e74a 100644
--- a/nuttx/arch/hc/src/m9s12/m9s12_ethernet.c
+++ b/nuttx/arch/hc/src/m9s12/m9s12_ethernet.c
@@ -265,7 +265,7 @@ static void emac_receive(FAR struct emac_driver_s *priv)
#endif
{
arp_ipin(&priv->d_dev);
- uip_input(&priv->d_dev);
+ devif_input(&priv->d_dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/arch/mips/src/pic32mx/pic32mx-ethernet.c b/nuttx/arch/mips/src/pic32mx/pic32mx-ethernet.c
index 808aba4ce..ef298668d 100644
--- a/nuttx/arch/mips/src/pic32mx/pic32mx-ethernet.c
+++ b/nuttx/arch/mips/src/pic32mx/pic32mx-ethernet.c
@@ -1436,7 +1436,7 @@ static void pic32mx_rxdone(struct pic32mx_driver_s *priv)
EMAC_STAT(priv, rx_ip);
arp_ipin(&priv->pd_dev);
- uip_input(&priv->pd_dev);
+ devif_input(&priv->pd_dev);
/* If the above function invocation resulted in data that
* should be sent out on the network, the field d_len will
diff --git a/nuttx/arch/sim/src/up_uipdriver.c b/nuttx/arch/sim/src/up_uipdriver.c
index 340b9ebf2..fd18b515e 100644
--- a/nuttx/arch/sim/src/up_uipdriver.c
+++ b/nuttx/arch/sim/src/up_uipdriver.c
@@ -167,7 +167,7 @@ void uipdriver_loop(void)
#endif
{
arp_ipin(&g_sim_dev);
- uip_input(&g_sim_dev);
+ devif_input(&g_sim_dev);
/* If the above function invocation resulted in data that
* should be sent out on the network, the global variable
diff --git a/nuttx/arch/z80/src/ez80/ez80_emac.c b/nuttx/arch/z80/src/ez80/ez80_emac.c
index 68de2457e..f67173793 100644
--- a/nuttx/arch/z80/src/ez80/ez80_emac.c
+++ b/nuttx/arch/z80/src/ez80/ez80_emac.c
@@ -1275,7 +1275,7 @@ static int ez80emac_receive(struct ez80emac_driver_s *priv)
EMAC_STAT(priv, rx_ip);
arp_ipin(&priv->dev);
- uip_input(&priv->dev);
+ devif_input(&priv->dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/drivers/net/cs89x0.c b/nuttx/drivers/net/cs89x0.c
index f0bad4600..38906b082 100644
--- a/nuttx/drivers/net/cs89x0.c
+++ b/nuttx/drivers/net/cs89x0.c
@@ -439,7 +439,7 @@ static void cs89x0_receive(struct cs89x0_driver_s *cs89x0, uint16_t isq)
#endif
{
arp_ipin(&cs89x0->cs_dev);
- uip_input(&cs89x0->cs_dev);
+ devif_input(&cs89x0->cs_dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/drivers/net/dm90x0.c b/nuttx/drivers/net/dm90x0.c
index 2a74ce2cb..58e9901bb 100644
--- a/nuttx/drivers/net/dm90x0.c
+++ b/nuttx/drivers/net/dm90x0.c
@@ -989,7 +989,7 @@ static void dm9x_receive(struct dm9x_driver_s *dm9x)
#endif
{
arp_ipin(&dm9x->dm_dev);
- uip_input(&dm9x->dm_dev);
+ devif_input(&dm9x->dm_dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/drivers/net/e1000.c b/nuttx/drivers/net/e1000.c
index ba0e0b124..272101290 100644
--- a/nuttx/drivers/net/e1000.c
+++ b/nuttx/drivers/net/e1000.c
@@ -574,7 +574,7 @@ static void e1000_receive(struct e1000_dev *e1000)
#endif
{
arp_ipin(&e1000->netdev);
- uip_input(&e1000->netdev);
+ devif_input(&e1000->netdev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/drivers/net/enc28j60.c b/nuttx/drivers/net/enc28j60.c
index 52538e575..e3d9d47aa 100644
--- a/nuttx/drivers/net/enc28j60.c
+++ b/nuttx/drivers/net/enc28j60.c
@@ -1379,7 +1379,7 @@ static void enc_rxdispatch(FAR struct enc_driver_s *priv)
{
nllvdbg("IP packet received (%02x)\n", BUF->type);
arp_ipin(&priv->dev);
- uip_input(&priv->dev);
+ devif_input(&priv->dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/drivers/net/encx24j600.c b/nuttx/drivers/net/encx24j600.c
index 28ed6da52..a0d90761a 100644
--- a/nuttx/drivers/net/encx24j600.c
+++ b/nuttx/drivers/net/encx24j600.c
@@ -1497,7 +1497,7 @@ static void enc_rxdispatch(FAR struct enc_driver_s *priv)
nllvdbg("Try to process IP packet (%02x)\n", BUF->type);
arp_ipin(&priv->dev);
- ret = uip_input(&priv->dev);
+ ret = devif_input(&priv->dev);
if (ret == OK || (clock_systimer() - descr->ts) > ENC_RXTIMEOUT)
{
diff --git a/nuttx/drivers/net/skeleton.c b/nuttx/drivers/net/skeleton.c
index 6730e6ef1..129554c3f 100644
--- a/nuttx/drivers/net/skeleton.c
+++ b/nuttx/drivers/net/skeleton.c
@@ -265,7 +265,7 @@ static void skel_receive(FAR struct skel_driver_s *skel)
#endif
{
arp_ipin(&skel->sk_dev);
- uip_input(&skel->sk_dev);
+ devif_input(&skel->sk_dev);
/* If the above function invocation resulted in data that should be
* sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/drivers/net/slip.c b/nuttx/drivers/net/slip.c
index 1a4873e77..1bc0a9d18 100644
--- a/nuttx/drivers/net/slip.c
+++ b/nuttx/drivers/net/slip.c
@@ -718,7 +718,7 @@ static int slip_rxtask(int argc, char *argv[])
priv->dev.d_len = priv->rxlen;
flags = net_lock();
- uip_input(&priv->dev);
+ devif_input(&priv->dev);
/* If the above function invocation resulted in data that should
* be sent out on the network, the field d_len will set to a
diff --git a/nuttx/drivers/net/vnet.c b/nuttx/drivers/net/vnet.c
index 315111722..c00e612b7 100644
--- a/nuttx/drivers/net/vnet.c
+++ b/nuttx/drivers/net/vnet.c
@@ -294,7 +294,7 @@ void rtos_vnet_recv(struct rgmp_vnet *rgmp_vnet, char *data, int len)
#endif
{
arp_ipin(&vnet->sk_dev);
- uip_input(&vnet->sk_dev);
+ devif_input(&vnet->sk_dev);
// If the above function invocation resulted in data that should be
// sent out on the network, the field d_len will set to a value > 0.
diff --git a/nuttx/include/nuttx/net/netdev.h b/nuttx/include/nuttx/net/netdev.h
index ccf891ae1..01f17a769 100644
--- a/nuttx/include/nuttx/net/netdev.h
+++ b/nuttx/include/nuttx/net/netdev.h
@@ -227,7 +227,7 @@ struct net_driver_s
* dev->d_len = devicedriver_poll();
* if (dev->d_len > 0)
* {
- * uip_input(dev);
+ * devif_input(dev);
* if (dev->d_len > 0)
* {
* devicedriver_send();
@@ -246,7 +246,7 @@ struct net_driver_s
* if (BUF->type == HTONS(UIP_ETHTYPE_IP))
* {
* arp_ipin();
- * uip_input(dev);
+ * devif_input(dev);
* if (dev->d_len > 0)
* {
* arp_out();
@@ -263,7 +263,7 @@ struct net_driver_s
* }
*/
-int uip_input(struct net_driver_s *dev);
+int devif_input(struct net_driver_s *dev);
/* Polling of connections
*
diff --git a/nuttx/net/devif/devif_input.c b/nuttx/net/devif/devif_input.c
index 56c73bc61..5080738f5 100644
--- a/nuttx/net/devif/devif_input.c
+++ b/nuttx/net/devif/devif_input.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * netuip/uip_input.c
+ * netuip/devif_input.c
* The uIP TCP/IP stack code.
*
* Copyright (C) 2007-2009, 2013-2014 Gregory Nutt. All rights reserved.
@@ -51,7 +51,7 @@
* well as some basic ICMP stuff). The implementation couples the IP,
* UDP, TCP and the application layers very tightly. To keep the size
* of the compiled code down, this code frequently uses the goto
* statement. While it would be possible to break the uip_input()
* function into many smaller functions, this would increase the code
* size because of the overhead of parameter passing and the fact that
* the optimizer would not be as efficient.
@@ -293,7 +293,7 @@ nullreturn:
****************************************************************************/
/****************************************************************************
- * Function: uip_input
+ * Function: devif_input
*
* Description:
*
@@ -307,7 +307,7 @@ nullreturn:
*
****************************************************************************/
-int uip_input(FAR struct net_driver_s *dev)
+int devif_input(FAR struct net_driver_s *dev)
{
FAR struct net_iphdr_s *pbuf = BUF;
uint16_t iplen;
@@ -51,7 +51,7 @@
* UDP, TCP and the application layers very tightly. To keep the size
* of the compiled code down, this code frequently uses the goto
- * statement. While it would be possible to break the uip_input()
+ * statement. While it would be possible to break the devif_input()
* function into many smaller functions, this would increase the code
* size because of the overhead of parameter passing and the fact that